<?php

/**
 * Plugin Name: [RW] Logotipos europeos en el footer
 * Description: Muestra los logotipos de la Unión Europea en el footer.
 * Version: 1.0.6
 * Author: Refineria
 * Author URI: https://refineria.es
 * Text Domain: rw-european-logos-footer
 */

define('EUROPEAN_LOGOS_FOOTER_VERSION', '1.0.3');
define('EUROPEAN_LOGOS_FOOTER_FILENAME', __FILE__);
define('EUROPEAN_LOGOS_FOOTER_INSTALLED', 'european_logos_footer_date_installed');
define('EUROPEAN_LOGOS_FOOTER_UPDATED', 'european_logos_footer_date_updated');

add_action('init', function () {
    load_plugin_textdomain('rw-european-logos-footer', false, dirname(plugin_basename(__FILE__)) . '/languages');
});

/**
 * Añadimos la vista al footer
 */
add_action('wp_footer', function () {
    include(plugin_dir_path(EUROPEAN_LOGOS_FOOTER_FILENAME) . 'inc/views/footer.php');
}, 999);

/**
 * Añadimos los estilos
 */
add_action('wp_enqueue_scripts', function () {
    wp_enqueue_style('european-logos-footer', plugins_url('public/css/european-logos-footer.css', EUROPEAN_LOGOS_FOOTER_FILENAME), [], EUROPEAN_LOGOS_FOOTER_VERSION);
});

/**
 * Añadimos fecha de instaladción del plugin
 */
add_filter('plugin_action_links', function ($links, $file) {


    $basename = plugin_basename(EUROPEAN_LOGOS_FOOTER_FILENAME);

    if ($file != $basename) {
        return $links;
    }

    $date_installed = get_option(EUROPEAN_LOGOS_FOOTER_INSTALLED, false);
    $date_updated = get_option(EUROPEAN_LOGOS_FOOTER_UPDATED, false);

    setlocale(LC_ALL, 'es_ES', 'Spanish_Spain', 'Spanish');
    if (is_numeric($date_installed)) {
        $links['installed_at'] = '<em>' . __('Installed on', 'rw-european-logos-footer') . ' ' . date('d/m/Y, H:i', $date_installed) . '</em>';
    }
    
    if (is_numeric($date_updated) && $date_installed != $date_updated) {
        $links['updated_at'] = '<em>' . __('Updated on', 'rw-european-logos-footer') . ' ' . date('d/m/Y, H:i', $date_updated) . '</em>';
    }

    return $links;
}, 10, 2);

/**
 * Guardamos fecha
 */

register_activation_hook(__FILE__, function () {
    $date_installed = get_option(EUROPEAN_LOGOS_FOOTER_INSTALLED, false);
    if (!$date_installed) {
        add_option(EUROPEAN_LOGOS_FOOTER_INSTALLED, time());
    }

    add_option(EUROPEAN_LOGOS_FOOTER_UPDATED, time());
});

/**
 * Borramos fecha de actualizaicón al desactivar
 */
register_deactivation_hook(__FILE__, function () {
    delete_option(EUROPEAN_LOGOS_FOOTER_UPDATED);
});
